#! /bin/bash

# Build generic binaries.
#
# We link libc dynamically, otherwise we get lots of problems loading
# .so files at runtime (either system stuff like NSS, or server
# plugins).
#
# We link libgcc statically (and avoid linking libstdc++ at all by
# CXX=gcc), to avoid reduce nasty library version dependencies.

# Abort on error
set -e

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"

TARBALL="${1}"
if [ -z "$TARBALL" ]; then
	echo 1>&2 "Usage: $0 tarball.tar.gz"
	exit 1
fi

WORKDIR="build-temp-$$"

if [ ! -f "$TARBALL" ]; then
	echo 1>&2 "Can't find tarball: $TARBALL"
	exit 1
else
	TARBALL="$(readlink -f "$TARBALL")"
fi

pushd ${BAKERY_BASE_DIR}/..
if [ ! -f .bzr-version ]; then
    echo "No bzr version info. You are not running this script from a"
    echo "properly exported bakery. Please do so. I will now quit."
    exit 1
else
    source .bzr-version
fi
popd

# Determine source name
#
SOURCE_DIR=$(basename ${TARBALL} .tar.gz)
BINDIST_NAME="${SOURCE_DIR}-$(uname -o | cut -d '/' -f 2)-$(uname -m)"
# for configure (shows up in SHOW GLOBAL VARIABLES LIKE 'version_%')
SERVER_SUFFIX="-ourdelta${REPO_VERSION}"
SERVER_COMMENT="(OurDelta - http://ourdelta.org/)"
SYSTEM_TYPE="$(uname -o)"
MACHINE_TYPE="$(uname -m)"

# We cannot have a slash '/' in tarfile name.
SYSTEM_TYPE="$(echo ${SYSTEM_TYPE} | sed -e 's/GNU\///')"

# Source our shared util functions.
#
. ${BAKERY_BASE_DIR}/util/util.sh

echo "Unpacking sources..."

mkdir "$WORKDIR"
cd "$WORKDIR"
tar zxf "$TARBALL"
cd "$SOURCE_DIR"

echo "Compiling ..."

get_cpuopt

# Use gcc rather than g++ to avoid linking libstdc++.so (which we don't need).

COMP="gcc -static-libgcc"
FLAGS="-O2 -fno-omit-frame-pointer -g -pipe -Wall $CPUOPT"

CC="$COMP" CXX="$COMP" CFLAGS="$FLAGS" CXXFLAGS="$FLAGS" \
	./configure \
	--prefix=/usr/local/mysql \
	--exec-prefix=/usr/local/mysql \
	--libexecdir=/usr/local/mysql/bin \
	--localstatedir=/usr/local/mysql/data \
	\
	--with-server-suffix="${SERVER_SUFFIX}" \
	--with-comment="${SERVER_COMMENT}" \
	--with-system-type="${SYSTEM_TYPE}" \
	--with-machine-type="${MACHINE_TYPE}" \
	\
	--enable-shared --enable-static \
	--with-client-ldflags=-static --with-mysqld-ldflags=-static \
	--enable-thread-safe-client --enable-local-infile --with-big-tables \
	--without-docs --with-extra-charsets=all \
	--with-libwrap --with-ssl --with-readline --with-libevent --with-zlib-dir=bundled \
	--with-partition --with-embedded-server \
	--with-plugins=max-no-ndb \
	--without-plugin-innodb_plugin \
	> ../../build.log 2>&1
make -j4 >> ../../build.log 2>&1

echo "Building binary distribution..."

scripts/make_binary_distribution  >> ../../build.log 2>&1
ORIG_TAR=$(echo mariadb-*.tar.gz)
ORIG_DIR=$(basename ${ORIG_TAR} .tar.gz)

rm -Rf $ORIG_DIR
tar zxf $ORIG_TAR
mv $ORIG_DIR "$BINDIST_NAME"
tar zcf "../../$BINDIST_NAME.tar.gz" "$BINDIST_NAME/"

cd ../..

echo "Successfully build generic bintar package $BINDIST_NAME.tar.gz"

exit 0
