#! /bin/bash

# Script to produce MariaDB source tarball from Launchpad bzr repo for OurDelta builds.
#
# Kristian Nielsen <knielsen@knielsen-hq.org>
# Arjen Lentz (arjen@openquery.com)

# Abort on error.
set -e

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"

# For a release, it is important to know which bzr revision was used
# to do the release. So fail if none specified, rather than default to
# latest.
#
# (One can specify last:1 for latest version).
#
# Also, it is best to use revid: specifications, as revno: numbers are
# not stable, and can change whenever new stuff is merged.
#
# After the release, the revision specified here should be tagged (or
# can specify tag: revision if placing tag before release).

BZR_REVSPEC="${1}"
if [ -z "$BZR_REVSPEC" ]; then
	echo 1>&2 "Usage: $0 bzr-revisionspec"
	exit 1
fi
BZR_BRANCH="${2}"
if [ -z "$BZR_BRANCH" ]; then
	BZR_BRANCH="lp:maria/5.1"
fi

. ${BAKERY_BASE_DIR}/../.bzr-version

echo "Checking out sources from bzr repo..."

# this can do terrible things if you run it in ~ (find a better way)
## Make sure we have a shared repository, so we don't have to download
## everything every time.
#
#bzr info . >/dev/null 2>&1 || bzr init-repo .

WORKDIR="build-temp-$$"
test -d "$WORKDIR" && rm -Rf "$WORKDIR"
#using export rather than checkout now, note that needs param swap
bzr export "$WORKDIR" "$BZR_BRANCH"

echo "Building..."

# Lets not default to make -j4, but actually check the number of cores.
MAKE_J="-j$(if [ -f /proc/cpuinfo ] ; then grep -c processor.* /proc/cpuinfo ; else echo 1 ; fi)"
if [ ${MAKE_J} = -j0 ]; then
  MAKE_J=-j1
fi

# Yes, we need to build mysqld just to make a source tarball :-(
#
# At least historically, the reason for this is that the windows build
# needs the sources to contain initial table files for installing the
# initial database (on Posix systems these are generated after
# building on the target system). And to generate them we need mysqld.
#
# Not sure if this has been fixed, if not we really ought to fix it ...
cd "$WORKDIR"
BUILD/autorun.sh > ../build.log 2>&1
CC=gcc CXX=gcc CFLAGS="-O0" CXXFLAGS="-O0" ./configure --prefix=/usr/local/mysql --exec-prefix=/usr/local/mysql --libexecdir=/usr/local/mysql/bin --localstatedir=/usr/local/mysql/data --enable-static --enable-thread-safe-client --enable-local-infile --with-big-tables --with-libwrap --with-ssl --without-docs --with-readline --with-extra-charsets=all --with-embedded-server --with-libevent --with-partition --with-zlib-dir=bundled --with-plugins=max-no-ndb --without-plugin-innodb_plugin >> ../build.log 2>&1
make ${MAKE_J} >> ../build.log 2>&1

echo "Making source tarball..."

make dist >> ../build.log 2>&1

# Grab the version info from configure.in to know tarball names.
set $(perl -ne 'print "$1 $2" if /AM_INIT_AUTOMAKE\((.*), (.*)\)/' configure.in)
ORIG_NAME="mysql"
echo  >.mariadb-version "PACKAGE_NAME=mariadb"
echo >>.mariadb-version "VERSION=$2"
echo >>.mariadb-version "RELEASE_NAME=ourdelta"
echo >>.mariadb-version "RELEASE_EXTRA="

source .mariadb-version

# Now re-pack the source tarball with a mariadb- prefix and an
# -ourdeltaN suffix so we can distinguish different builds from the
# same MariaDB upstream source.
BASEDIR="${ORIG_NAME}-${VERSION}"
rm -Rf "${BASEDIR}/"
tar zxf "${BASEDIR}.tar.gz"
NEWBASE="${PACKAGE_NAME}-${VERSION}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}${REPO_VERSION}"
rm -Rf "${NEWBASE}"
mv "${BASEDIR}" "${NEWBASE}"
# put .mariadb-version file into source tarball
cp .mariadb-version "${NEWBASE}/"
TARBALL="${NEWBASE}.tar.gz"
tar zcf "${TARBALL}" "${NEWBASE}/"
mv "$TARBALL" ..
cd ..
rm -Rf "$WORKDIR"

echo "Successfully made source tarball $TARBALL"
